@@ -11,7 +11,8 @@
 // A and C are of the same dimensions
 // B and I are of the same dimensions
 //==============================================================
-SEXP R_hadamard(SEXP nrowA_, SEXP ncolA_, SEXP A_,
+SEXP R_hadamard(SEXP a_,
+                SEXP nrowA_, SEXP ncolA_, SEXP A_,
                 SEXP nrowB_, SEXP ncolB_, SEXP B_,
                 SEXP C_,  // Optional matrix of the same dimension as A
                 SEXP irowA_, SEXP icolA_,
@@ -25,6 +26,7 @@ SEXP R_hadamard(SEXP nrowA_, SEXP ncolA_, SEXP A_,
     //int ncolA = INTEGER_VALUE(ncolA_);
     int nrowB = INTEGER_VALUE(nrowB_);
     //int ncolB = INTEGER_VALUE(ncolB_);
+    double a = NUMERIC_VALUE(a_);
     int drop = asLogical(drop_);
     int makedimnames = asLogical(makedimnames_);
     int inplace = INTEGER_VALUE(inplace_);
@@ -97,7 +99,6 @@ SEXP R_hadamard(SEXP nrowA_, SEXP ncolA_, SEXP A_,
     }
 
     // Rprintf(" Making the Hadamard product ...\n");
-    double a = 1.0;
     size_t j;
     for(j=0; j<ncol; j++){
       hadam_set(nrow, &a, A + (long long)nrowA*icolA[j], irowA, B + (long long)nrowB*icolB[j], irowB, out2 + nrow*j);
@@ -113,8 +114,7 @@ SEXP R_hadamard(SEXP nrowA_, SEXP ncolA_, SEXP A_,
       size_t i;
       for(j=0; j<ncol; j++){
         for(i=0; i<nrow; i++){
-          if(irowB[i] == icolB[j]){ //if(irowA[i] == icolA[j]){
-            //out2[nrow*j + i] += C[nrowB*(long long)icolB[j] + (long long)irowB[i]];
+          if(irowB[i] == icolB[j]){
             out2[nrow*j + i] += C[nrowA*(long long)icolA[j] + (long long)irowA[i]];
           }
         }
@@ -124,16 +124,12 @@ SEXP R_hadamard(SEXP nrowA_, SEXP ncolA_, SEXP A_,
     if(ismatrix && makedimnames && (inplace==0)){
       // Rprintf(" Making dimnames ...\n");
       SEXP dimnames_ = PROTECT(Rf_allocVector(VECSXP, 2));
+      SEXP dimnamesA_ = PROTECT(Rf_getAttrib(A_, R_DimNamesSymbol));
+      SEXP dimnamesB_ = PROTECT(Rf_getAttrib(B_, R_DimNamesSymbol));
       get_dimnames(nrow, ncol, irowA, irowB, NULL, icolA, icolB, NULL,
-                   Rf_getAttrib(A_, R_DimNamesSymbol),
-                   Rf_getAttrib(B_, R_DimNamesSymbol),
-                   dimnames_);
+                   dimnamesA_, dimnamesB_, dimnames_);
       Rf_setAttrib(out2_, R_DimNamesSymbol, dimnames_);
-      //setAttrib(out2_, R_DimNamesSymbol,
-      //          get_dimnames(nrow,ncol,irowA,irowB,NULL,icolA,icolB,NULL,
-      //                       getAttrib(A_, R_DimNamesSymbol),
-      //                       getAttrib(B_, R_DimNamesSymbol)));
-      nprotect++;
+      nprotect += 3;
     }
 
     UNPROTECT(nprotect);
